@@ -1,6 +1,6 @@
 package Padre::Document::LaTeX::Syntax;
 BEGIN {
-  $Padre::Document::LaTeX::Syntax::VERSION = '0.08';
+  $Padre::Document::LaTeX::Syntax::VERSION = '0.09';
 }
 
 # ABSTRACT: Latex document syntax-checking in the background
@@ -10,35 +10,56 @@ use warnings;
 
 our @ISA = 'Padre::Task::Syntax';
 
-use Padre::Wx;
+sub new {
+	my $class = shift;
+
+	my %args = @_;
+
+	my $self = $class->SUPER::new(%args);
+
+	return $self;
+}
 
 
 sub syntax {
 	my $self = shift;
 	my $text = shift;
 
-	my $filename = $self->{filename};
+	my $filename    = $self->{filename};
+	my $project_dir = $self->{project};
 
-	# TODO check for pdflatex
-	my $pdflatex_command = "pdflatex -file-line-error -draftmode -interaction nonstopmode $filename";
+	my $pdflatex_command = "cd $project_dir; pdflatex -file-line-error -draftmode -interaction nonstopmode $filename";
 	my $output           = `$pdflatex_command`;
 
-	## 	./camra-uhi.tex:292: Paragraph ended before \begin was complete.
+	warn "Complete output: >>>$output<<<\n";
+
+	my @lines = split /\n/, $output;
 	my @issues = ();
 
-	# push @issues, { msg => $2, line => $1, severity => Padre::Wx::MarkError, desc => '' };
-
 	LINE:
-	foreach my $line ( split /\n/, $output ) {
-		next LINE if not $line =~ /.*:(\d+):\s*(.*)/;
+	for ( my $i = 0; $i < scalar @lines; $i++ ) {
+		my $line = $lines[$i];
 
-		warn "line: $line\n";
+		next LINE if not $line =~ /.*:(\d+):\s*(.*)/;
+		my $line_no   = $1;
+		my $error_msg = $2;
+
+		warn "line: '$line'\n";
+
+		while ( ++$i < scalar @lines && $lines[$i] !~ /^\[\d+\]/ ) {
+			$lines[$i] =~ s/^l\.\d+ / /;
+			$error_msg .= $lines[$i];
+		}
+
+		$error_msg =~ s/\s+/ /g;
+
+		warn "$line_no: '$error_msg'\n";
 
 		my %issue = (
-			msg      => $2,
-			line     => $1,
-			severity => Padre::Wx::MarkError,
-			desc     => '',
+			line    => $line_no,
+			file    => $filename,
+			type    => 'F',
+			message => $error_msg,
 		);
 
 		push @issues, \%issue;
@@ -59,20 +80,11 @@ Padre::Document::LaTeX::Syntax - Latex document syntax-checking in the backgroun
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
-  # by default, the text of the current document
-  # will be fetched
-  my $task = Padre::Document::LaTeX::Syntax->new();
-  $task->schedule;
-
-  my $task2 = Padre::Document::LaTeX::Syntax->new(
-    text          => Padre::Documents->current->text_get,
-    filename      => Padre::Documents->current->editor->{Document}->filename,
-  );
-  $task2->schedule;
+Syntax checking for LaTeX documents
 
 =head1 DESCRIPTION
 
@@ -102,7 +114,7 @@ Ahmad M. Zawawi <ahmad.zawawi@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Zeno Gantner, Ahmad M. Zawawi.
+This software is copyright (c) 2011 by Zeno Gantner, Ahmad M. Zawawi.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
